@@ -1,6 +1,6 @@
 use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.153360';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.160822';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
@@ -14,6 +14,7 @@ our $INDENT_BINDING = 0;
 
 my @generic_controls = qw(
 		Accordion
+		ActionSheet
 		Autocomplete
 		Box
 		CheckBox
@@ -21,6 +22,7 @@ my @generic_controls = qw(
 		ColorBox
 		ContextMenu
 		DateBox
+		DeferRendering
 		FileUploader
 		Gallery
 		List
@@ -30,6 +32,8 @@ my @generic_controls = qw(
 		MultiView
 		NavBar
 		NumberBox
+		Panorama
+		Pivot
 		PivotGrid
 		PivotGridFieldChooser
 		Popover
@@ -46,11 +50,21 @@ my @generic_controls = qw(
 		TabPanel
 		Tabs
 		TagBox
-		TextAread
+		TextArea
 		TextBox
 		TitleView
+		Toast
+		Toolbar
+		TreeView
 	);
 
+#Helper method to export without prepending a prefix
+my @without_prefix = qw( dxbuild required_assets require_asset indent_binding append_js prepend_js );
+
+#Helper method to export with prepending a prefix
+my @with_prefix = (qw( Button DataGrid Form Popup Menu LoadPanel Lookup ),
+				   @generic_controls);
+
 
 sub out{
 	my $tag = shift;
@@ -99,8 +113,17 @@ sub dxbind{
 	#http://stackoverflow.com/questions/9930577/jquery-dot-in-id-selector
 	my $jquery_id = $id;
 	$jquery_id =~ s{\.}{\\\\.}g;
-	my $binding = '$("#'.$jquery_id.'").'.$control.'(';
+	my $prepend = ref $attrs eq 'HASH' && delete $attrs->{prependTo};
+	my $append  = ref $attrs eq 'HASH' && delete $attrs->{appendTo};
+	my $binding = '';
+	if($prepend || $append){
+		$binding = '$(\'<div id="'.$id.'">\').'.$control.'(';
+	}
+	else{
+		$binding = '$("#'.$jquery_id.'").'.$control.'(';
+	}
     my @options;
+
 	if (ref($attrs) eq 'HASH') {
 		$binding .= '{';
 		$binding .= "\n  " if $INDENT_BINDING;
@@ -121,11 +144,18 @@ sub dxbind{
 	}
     $binding .= join ",\n".($INDENT_BINDING?'  ':''), @options;
 	$binding .= '}' if ref($attrs) eq 'HASH';
-    $binding .= ');' . ($INDENT_BINDING?"\n":"");
+    $binding .= ')';
+	$binding .= '.prependTo("'.$prepend.'")' if $prepend;
+	$binding .= '.appendTo("'.$append.'")'   if $append;
+	$binding .= ';' . ($INDENT_BINDING?"\n":"");
 	#append some extensions (eg: dxdatagrid)
 	$binding .= join ";\n".($INDENT_BINDING?'  ':''), @$extensions if defined $extensions;
 	$c->stash('dxHelper')->add_binding($binding);
-	out join('',@$befores).'<div id="'.$id.'"></div>'.join('',@$afters);
+	my $html_code = "<div id=\"$id\"></div>";
+	if($prepend || $append){
+		$html_code = '';
+	}
+	out join('',@$befores, $html_code ,@$afters);
 }
 
 
@@ -202,6 +232,15 @@ sub dxdatagrid{
 }
 
 
+sub dxform{
+	my $c = shift;
+	my $attrs = parse_attributs( $c, [qw(id %formData @items)], @_ );
+	my $id = delete($attrs->{id}) // new_id( $c, $attrs );
+	
+	dxbind( $c, 'dxForm' => $id => $attrs );
+}
+
+
 sub dxpopup{
 	my $c = shift;
 	my $attrs = parse_attributs( $c, [qw(id title contentTemplate)], @_ );
@@ -244,17 +283,19 @@ sub mk_dxcontrol{
 
 
 sub dxbuild {
-	my $c = shift;
+	my $c    = shift;
+	my %opts = @_;
 	my $dxhelper = $c->stash('dxHelper') or return;
 	if($dxhelper->{bindings}){
-		out '<script language="javascript">$(window).on("load",function(){'.
+		out '<script language="javascript">'.
+			($opts{js_prefix}//'$(window).on("load",function(){') .
 			"\n".
 			join("\n",
 				 grep{ ($_//'') ne ''}
 				 @$dxhelper{'before_bindings','bindings','after_bindings'}
 			).
 			"\n".
-			'});</script>';
+			($opts{js_sufix}//'});').'</script>';
 	}
 }
 
@@ -302,12 +343,6 @@ sub append_js{
 	}
 }
 
-#Helper method to export without prepending a prefix
-my @without_prefix = qw( dxbuild required_assets require_asset indent_binding append_js prepend_js );
-
-#Helper method to export with prepending a prefix
-my @with_prefix = (qw( Button DataGrid Popup Menu LoadPanel Lookup ),
-				   @generic_controls);
 sub register {
 	my ( $self, $app, $args ) = @_;
 	my $tp = $args->{tag_prefix};
@@ -356,7 +391,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.153360
+version 0.160822
 
 =head1 SUBROUTINES/METHODS
 
@@ -402,7 +437,7 @@ Internal usage.
 	dxbind( $c, 'dxButton' => $id => $attrs, \@extensions);
 
 Produce a div tag with an computed id, which will be binded to
-a dxButton with C<$attrs> attributs at call to dxbuild
+a dxButton with C<$attrs> attributs at call to dxbuild.
 
 =head2 parse_attributs
 
@@ -445,6 +480,16 @@ B<Note: It will ignore all other options specified in the hash reference.>
 
 	%= dxdatagrid myId, { options => 'JSFrameWork.gridsOptions.myResource' }
 
+=head2 dxform C<[ $id, [ $formData, [ \@itemsSpecs ], [ \%opts ] ] ]>
+
+	%= dxform myForm => \%formData;
+	
+	%= dxform myForm => \%formData, { colCount => 2 };
+	
+	%= dxform myForm => \%formData, \%itemsSpecs;
+	
+	%= dxform myForm => \%formData, \%itemsSpecs, { colCount => '3' };
+
 =head2 dxpopup C<[ $id, [ $title, [ $contentTemplate, ] ] ], [\%opts]>
 
 	%= dxpopup myPopupID => 'Popup Title', \q{function(contentElement){
@@ -469,10 +514,12 @@ In your template:
 	%= dxlookup 'name' => $value => 'Name: ', { dataSource => $ds, valueExpr=> $ve, displayExpr => $de }
 	%= dxselectbox 'name' => $value => 'Name: ', { dataSource => $ds, valueExpr=> $ve, displayExpr => $de }
 
-=head2 dxbuild
+=head2 dxbuild C<[ js_prefix => '$(function(){', js_sufix => '});' ]>
 
 Build the binding between jQuery and divs generated by plugin helpers such as dxbutton.
 It is should to be called in your template just before you close the body tag.
+Optional named argument C<js_prefix> and C<js_sufix> can be specified to override
+standard javascript wrapper.
 
 	<body>
 		...
